@@ -1,20 +1,21 @@
 # noinspection PyUnresolvedReferences
-from .builtins import map
-
-# noinspection PyUnresolvedReferences
+# flake8: noqa
 from . import op
 
-# noinspection PyUnresolvedReferences
-from ._placeholder import _
-
 # noinspection PyUnresolvedReferences
 from .functions import *
 
-# noinspection PyUnresolvedReferences
-from .magics import X, Y, m
-
 # noinspection PyUnresolvedReferences
 from .seq import *
 
 # noinspection PyUnresolvedReferences
 from .pred import *
+
+# noinspection PyUnresolvedReferences
+from .proxy import *
+
+# noinspection PyUnresolvedReferences
+from .properties import *
+
+# noinspection PyUnresolvedReferences
+from .types import *
