@@ -2,13 +2,19 @@ from invoke import task
 
 
 @task
-def test(ctx, all=False):
+def test(ctx, all=False, maxfail=None, verbose=False):
     """
     Run tests.
     """
+    flags = []
     if all:
         doctest(ctx)
-    ctx.run("pytest tests/", pty=True)
+    else:
+        flags.extend(["--lf", f"--maxfail={maxfail or 2}"])
+    if verbose:
+        flags.append("-vv")
+    flags = " ".join(flags)
+    ctx.run(f"python -c 'import sidekick.api' && pytest tests/ {flags}", pty=True)
 
 
 @task
@@ -41,3 +47,13 @@ def check_style(ctx):
     """
     ctx.run("black . --check")
     ctx.run("flake8 sidekick")
+
+
+@task
+def ci(ctx):
+    """
+    Run code that should be executed in continuous integration.
+    """
+    test(ctx, all=True)
+    docs(ctx, strict=True, clear=True)
+    # check_style(ctx)
